@@ -256,6 +256,8 @@ def case_setup(tmpdir, debugger_runner_simple):
         def test_file(
                 self,
                 filename,
+                wait_for_port=True,
+                wait_for_initialization=True,
                 **kwargs
             ):
             import shutil
@@ -282,7 +284,11 @@ def case_setup(tmpdir, debugger_runner_simple):
                 assert hasattr(WriterThread, key)
                 setattr(WriterThread, key, value)
 
-            with runner.check_case(WriterThread) as writer:
+            with runner.check_case(
+                    WriterThread,
+                    wait_for_port=wait_for_port,
+                    wait_for_initialization=wait_for_initialization
+                ) as writer:
                 yield writer
 
     return CaseSetup()
@@ -489,10 +495,10 @@ def case_setup_django(debugger_runner_simple):
             version = [int(x) for x in django.get_version().split('.')][:2]
             if version == [1, 7]:
                 django_folder = 'my_django_proj_17'
-            elif version in ([2, 1], [2, 2], [3, 0], [3, 1]):
+            elif version in ([2, 1], [2, 2], [3, 0], [3, 1], [3, 2]):
                 django_folder = 'my_django_proj_21'
             else:
-                raise AssertionError('Can only check django 1.7, 2.1, 2.2, 3.0 and 3.1 right now. Found: %s' % (version,))
+                raise AssertionError('Can only check django 1.7, 2.1, 2.2, 3.0, 3.1 and 3.2 right now. Found: %s' % (version,))
 
             WriterThread.DJANGO_FOLDER = django_folder
             for key, value in kwargs.items():
