@@ -8,8 +8,9 @@ from robotframework_ls.impl.protocols import (
     IKeywordFound,
     ICompletionContext,
     IKeywordCollector,
+    IKeywordArg,
+    ILibraryDoc,
 )
-from robotframework_ls.impl.robot_specbuilder import KeywordArg
 from typing import Tuple, Sequence, List, Dict, Optional
 
 
@@ -61,7 +62,7 @@ class _KeywordFoundFromAst(object):
         module_ast,
         keyword_node,
         keyword_name,
-        keyword_args: Sequence[KeywordArg],
+        keyword_args: Sequence[IKeywordArg],
         completion_context,
         completion_item_kind,
     ):
@@ -82,7 +83,7 @@ class _KeywordFoundFromAst(object):
         return self._keyword_name
 
     @property
-    def keyword_args(self) -> Sequence[KeywordArg]:
+    def keyword_args(self) -> Sequence[IKeywordArg]:
         return self._keyword_args
 
     @property
@@ -114,6 +115,13 @@ class _KeywordFoundFromAst(object):
 
         return _build_docs(self.keyword_name, args, docs, "markdown")
 
+    @property
+    @instance_cache
+    def docs_without_signature(self) -> str:
+        from robotframework_ls.impl import ast_utils
+
+        return ast_utils.get_documentation(self._keyword_node)
+
     @property
     @instance_cache
     def source(self) -> str:
@@ -175,7 +183,7 @@ class _KeywordFoundFromLibrary(object):
         library_doc,
         keyword_doc,
         keyword_name,
-        keyword_args: Sequence[KeywordArg],
+        keyword_args: Sequence[IKeywordArg],
         completion_context,
         completion_item_kind,
         library_alias=None,
@@ -195,7 +203,7 @@ class _KeywordFoundFromLibrary(object):
         return self._keyword_name
 
     @property
-    def keyword_args(self) -> Sequence[KeywordArg]:
+    def keyword_args(self) -> Sequence[IKeywordArg]:
         return self._keyword_args
 
     @property
@@ -268,6 +276,14 @@ class _KeywordFoundFromLibrary(object):
         docs, _docs_format = self._docs_and_format
         return docs
 
+    @property
+    @instance_cache
+    def docs_without_signature(self):
+        from robotframework_ls.impl.robot_specbuilder import docs_and_format
+
+        docs, _docs_format = docs_and_format(self._keyword_doc)
+        return docs
+
     @property
     @instance_cache
     def docs_format(self):
@@ -283,6 +299,7 @@ def _collect_completions_from_ast(
 ):
     from robotframework_ls.impl import ast_utils
     from robocorp_ls_core.lsp import CompletionItemKind
+    from robotframework_ls.impl.robot_specbuilder import KeywordArg
 
     found = {}
 
@@ -331,6 +348,9 @@ def _collect_libraries_keywords(
     """
     :param CompletionContext completion_context:
     """
+    from robotframework_ls.impl.libspec_manager import LibspecManager
+    from robotframework_ls.impl.protocols import ILibraryDocOrError
+
     # Get keywords from libraries
     from robotframework_ls.impl.robot_constants import BUILTIN_LIB
     from robocorp_ls_core.lsp import CompletionItemKind
@@ -362,7 +382,7 @@ def _collect_libraries_keywords(
             library_infos[lib_info] = True
 
     library_infos[_LibInfo(BUILTIN_LIB, None, True, None, None)] = True
-    libspec_manager = completion_context.workspace.libspec_manager
+    libspec_manager: LibspecManager = completion_context.workspace.libspec_manager
 
     for library_info in library_infos:
         completion_context.check_cancelled()
@@ -371,13 +391,16 @@ def _collect_libraries_keywords(
         ):
             continue
 
-        library_doc = libspec_manager.get_library_info(
-            library_info.name,
-            create=True,
-            current_doc_uri=completion_context.doc.uri,
-            builtin=library_info.builtin,
-            args=library_info.args,
+        library_doc_or_error: ILibraryDocOrError = (
+            libspec_manager.get_library_doc_or_error(
+                library_info.name,
+                create=True,
+                current_doc_uri=completion_context.doc.uri,
+                builtin=library_info.builtin,
+                args=library_info.args,
+            )
         )
+        library_doc = library_doc_or_error.library_doc
         if library_doc is not None:
             #: :type keyword: KeywordDoc
             for keyword in library_doc.keywords:
@@ -399,9 +422,15 @@ def _collect_libraries_keywords(
                             library_alias=library_info.alias,
                         )
                     )
+
+            collector.on_resolved_library(
+                completion_context, library_info.node, library_doc
+            )
         else:
             from robot.api import Token
 
+            error_msg = library_doc_or_error.error
+
             node = library_info.node
             node_name_tok = node.get_token(Token.NAME)
             if node_name_tok is not None:
@@ -412,6 +441,7 @@ def _collect_libraries_keywords(
                     node_name_tok.lineno,
                     node_name_tok.col_offset,
                     node_name_tok.end_col_offset,
+                    error_msg,
                 )
             else:
                 collector.on_unresolved_library(
@@ -421,6 +451,7 @@ def _collect_libraries_keywords(
                     node.end_lineno,
                     node.col_offset,
                     node.end_col_offset,
+                    error_msg,
                 )
 
 
@@ -483,6 +514,14 @@ class _CollectKeywordNameToKeywordFound:
             self.keyword_name_to_keyword_found[keyword_found.keyword_name] = lst = []
         lst.append(keyword_found)
 
+    def on_resolved_library(
+        self,
+        completion_context: ICompletionContext,
+        library_node,
+        library_doc: ILibraryDoc,
+    ):
+        pass
+
     def on_unresolved_library(
         self,
         completion_context: ICompletionContext,
@@ -491,6 +530,7 @@ class _CollectKeywordNameToKeywordFound:
         end_lineno: int,
         col_offset: int,
         end_col_offset: int,
+        error_msg: Optional[str],
     ):
         pass
 
