@@ -12,6 +12,12 @@ OPTION_ROBOT_VARIABLES = "robot.variables"
 
 OPTION_ROBOT_LINT_ROBOCOP_ENABLED = "robot.lint.robocop.enabled"
 
+OPTION_ROBOT_LINT_ENABLED = "robot.lint.enabled"
+OPTION_ROBOT_LINT_UNDEFINED_KEYWORDS = "robot.lint.undefinedKeywords"
+OPTION_ROBOT_LINT_UNDEFINED_LIBRARIES = "robot.lint.undefinedLibraries"
+OPTION_ROBOT_LINT_UNDEFINED_RESOURCES = "robot.lint.undefinedResources"
+OPTION_ROBOT_LINT_KEYWORD_CALL_ARGUMENTS = "robot.lint.keywordCallArguments"
+
 OPTION_ROBOT_CODE_FORMATTER = "robot.codeFormatter"
 
 OPTION_ROBOT_CODE_FORMATTER_ROBOTIDY = "robotidy"
@@ -54,6 +60,11 @@ ALL_ROBOT_OPTIONS = frozenset(
         OPTION_ROBOT_WORKSPACE_SYMBOLS_ONLY_FOR_OPEN_DOCS,
         OPTION_ROBOT_COMPLETION_KEYWORDS_FORMAT,
         OPTION_ROBOT_LIBRARIES_LIBDOC_NEEDS_ARGS,
+        OPTION_ROBOT_LINT_ENABLED,
+        OPTION_ROBOT_LINT_UNDEFINED_KEYWORDS,
+        OPTION_ROBOT_LINT_UNDEFINED_LIBRARIES,
+        OPTION_ROBOT_LINT_UNDEFINED_RESOURCES,
+        OPTION_ROBOT_LINT_KEYWORD_CALL_ARGUMENTS,
     )
 )
 
