@@ -26,7 +26,11 @@ from robotframework_ls import __version__, rf_interactive_integration
 import typing
 import sys
 from robocorp_ls_core.watchdog_wrapper import IFSObserver
-from robocorp_ls_core.lsp import CodeLensTypedDict, TextDocumentPositionParamsTypedDict
+from robocorp_ls_core.lsp import (
+    CodeLensTypedDict,
+    TextDocumentPositionParamsTypedDict,
+    PositionTypedDict,
+)
 from robotframework_ls.commands import (
     ROBOT_GET_RFLS_HOME_DIR,
     ROBOT_START_INDEXING_INTERNAL,
@@ -358,7 +362,10 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
             # Note that there are no auto-trigger characters (there's no good
             # character as there's no `(` for parameters and putting it as a
             # space becomes a bit too much).
-            "signatureHelpProvider": {"triggerCharacters": []},
+            # Under review: added ' ' and '\t' now that we have info on the
+            # active parameter (waiting for feedback from community here to
+            # check whether this is good or annoying).
+            "signatureHelpProvider": {"triggerCharacters": [" ", "\t"]},
             "textDocumentSync": {
                 "change": TextDocumentSyncKind.INCREMENTAL,
                 "save": {"includeText": False},
@@ -401,6 +408,24 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
     def _start_indexing(self, *arguments):
         self._server_manager.get_regular_rf_api_client("")
 
+    def m_robot__provide_evaluatable_expression(
+        self, uri: str, position: PositionTypedDict
+    ):
+        rf_api_client = self._server_manager.get_others_api_client(uri)
+        if rf_api_client is not None:
+            func = partial(
+                self._async_api_request,
+                rf_api_client,
+                "request_evaluatable_expression",
+                doc_uri=uri,
+                position=position,
+            )
+            func = require_monitor(func)
+            return func
+
+        log.info("Unable to provide evaluatable expression (no api available).")
+        return None
+
     @command_dispatcher(ROBOT_WAIT_FULL_TEST_COLLECTION_INTERNAL)
     def _wait_for_full_test_collection(self, *arguments):
         rf_api_client = self._server_manager.get_regular_rf_api_client("")
@@ -438,11 +463,17 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
             )
             from robotframework_ls.ep_resolve_interpreter import IInterpreterInfo
 
-            target_robot: str = arguments[0]
+            target_robot = arguments[0]
+
+            if isinstance(target_robot, (list, tuple)):
+                if len(target_robot) > 0:
+                    target_robot = target_robot[0]
+
+            robot_uri = uris.from_fs_path(target_robot)
 
             for ep in self._pm.get_implementations(EPResolveInterpreter):
                 interpreter_info: IInterpreterInfo = (
-                    ep.get_interpreter_info_for_doc_uri(uris.from_fs_path(target_robot))
+                    ep.get_interpreter_info_for_doc_uri(robot_uri)
                 )
                 if interpreter_info is not None:
                     return {
@@ -646,7 +677,6 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
     ) -> list:
         from robotframework_ls.impl.completion_context import CompletionContext
         from robotframework_ls.impl import section_completions
-        from robotframework_ls.impl import snippets_completions
         from robocorp_ls_core.client_base import wait_for_message_matchers
 
         ws = self.workspace
@@ -668,7 +698,6 @@ class RobotFrameworkLanguageServer(PythonLanguageServer):
 
         # These run locally (no need to get from the server).
         completions.extend(section_completions.complete(ctx))
-        completions.extend(snippets_completions.complete(ctx))
 
         accepted_message_matchers = wait_for_message_matchers(
             message_matchers,
