@@ -21,6 +21,7 @@ from robotframework_ls.impl.protocols import IKeywordFound, IDefinition
 from robocorp_ls_core.watchdog_wrapper import IFSObserver
 import itertools
 import typing
+import sys
 
 
 log = get_logger(__name__)
@@ -76,16 +77,29 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         try:
             import robot  # noqa
         except:
-            log.exception("Unable to import 'robot'.")
-            version = "NO_ROBOT"
+            version = (
+                'Error in "import robot".\n'
+                f"It seems that Robot Framework is not installed in {sys.executable}.\n"
+                "Please install it in your environment and restart the Robot Framework Language Server\n"
+                'or set: "robot.language-server.python" or "robot.python.executable"\n'
+                "to point to a python installation that has Robot Framework installed.\n"
+                "Hint: with pip it can be installed with:\n"
+                f"{sys.executable} -m pip install robotframework\n"
+            )
+            log.exception(version)
         else:
             try:
                 from robot import get_version
 
                 version = get_version(naked=True)
             except:
-                log.exception("Unable to get version.")
-                version = "N/A"  # Too old?
+                version = (
+                    'Error calling "robot.get_version()".\n'
+                    f"If the module: {robot}\n"
+                    "is a module from your project, please rename it (as it is shadowing the Robot Framework `robot` package)\n"
+                    "and restart the Robot Framework Language Server."
+                )
+                log.exception(version)
         self._version = version
         return self._version
 
@@ -134,11 +148,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         if not self._check_min_version((3, 2)):
             from robocorp_ls_core.lsp import Error
 
-            msg = (
-                "robotframework version (%s) too old for linting.\n"
-                "Please install a newer version and restart the language server."
-                % (self.m_version(),)
-            )
+            msg = self.m_version()
             log.info(msg)
             return [Error(msg, (0, 0), (1, 0)).to_lsp_diagnostic()]
 
@@ -153,6 +163,9 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         )
         from robocorp_ls_core import uris
         from robocorp_ls_core.lsp import Error
+        from robotframework_ls.impl.robot_lsp_constants import (
+            OPTION_ROBOT_LINT_ENABLED,
+        )
 
         try:
             from robotframework_ls.impl.ast_utils import collect_errors
@@ -176,10 +189,21 @@ class RobotFrameworkServerApi(PythonLanguageServer):
             errors = collect_errors(ast)
             log.debug("Collected AST errors (in thread): %s", len(errors))
             monitor.check_cancelled()
-            analysis_errors = code_analysis.collect_analysis_errors(completion_context)
-            monitor.check_cancelled()
-            log.debug("Collected analysis errors (in thread): %s", len(analysis_errors))
-            errors.extend(analysis_errors)
+
+            lint_ls_enabled = config is None or config.get_setting(
+                OPTION_ROBOT_LINT_ENABLED, bool, True
+            )
+            if lint_ls_enabled:
+                analysis_errors = code_analysis.collect_analysis_errors(
+                    completion_context
+                )
+                monitor.check_cancelled()
+                log.debug(
+                    "Collected analysis errors (in thread): %s", len(analysis_errors)
+                )
+                errors.extend(analysis_errors)
+            else:
+                log.debug("Language server linting disabled.")
 
             lsp_diagnostics = [error.to_lsp_diagnostic() for error in errors]
 
@@ -235,7 +259,11 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         if completion_context is None:
             return []
 
-        return self._complete_from_completion_context(completion_context)
+        from robotframework_ls.impl import snippets_completions
+
+        completions = snippets_completions.complete(completion_context)
+        completions.extend(self._complete_from_completion_context(completion_context))
+        return completions
 
     def _complete_from_completion_context(self, completion_context):
         from robotframework_ls.impl import section_name_completions
@@ -609,6 +637,28 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
         return list_tests(completion_context)
 
+    def m_evaluatable_expression(self, doc_uri: str, position: PositionTypedDict):
+        func = partial(self._threaded_evaluatable_expression, doc_uri, position)
+        func = require_monitor(func)
+        return func
+
+    def _threaded_evaluatable_expression(
+        self, doc_uri: str, position: PositionTypedDict, monitor: IMonitor
+    ) -> Optional[dict]:
+        from robotframework_ls.impl.provide_evaluatable_expression import (
+            provide_evaluatable_expression,
+        )
+
+        line = position["line"]
+        col = position["character"]
+        completion_context = self._create_completion_context(
+            doc_uri, line, col, monitor
+        )
+        if completion_context is None:
+            return None
+
+        return provide_evaluatable_expression(completion_context)
+
     def m_wait_for_full_test_collection(self):
         func = partial(self._threaded_wait_for_full_test_collection)
         func = require_monitor(func)
