@@ -1,6 +1,8 @@
 import itertools
 import socket as socket_module
 import sys
+import time
+import random
 import threading
 from functools import partial
 from typing import Optional, List, Dict, Tuple, Sequence
@@ -21,7 +23,7 @@ class _RemoteFSWatch(object):
     def __init__(
         self,
         remote_fs_observer: "RemoteFSObserver",
-        on_change_id: int,
+        on_change_id: str,
         on_change: IFSCallback,
         call_args=(),
     ):
@@ -64,15 +66,20 @@ class RemoteFSObserver(object):
         self.writer: Optional[JsonRpcStreamWriter] = None
         self.reader_thread: Optional[threading.Thread] = None
 
-        self._next_id: "partial[int]" = partial(next, itertools.count())
-        self._change_id_to_fs_watch: Dict[int, _RemoteFSWatch] = {}
+        self._counter: "partial[int]" = partial(next, itertools.count())
+        self._change_id_to_fs_watch: Dict[str, _RemoteFSWatch] = {}
 
         self._socket: Optional[socket_module.socket] = None
         self._backend = backend
         self._extensions = extensions
         self._initialized_event = threading.Event()
 
-    def start_server(self, log_file: Optional[str] = None) -> int:
+    def _next_id(self) -> str:
+        return f"{os.getpid()} - {self._counter()} - {random.random()}"
+
+    def start_server(
+        self, log_file: Optional[str] = None, verbose: Optional[int] = None
+    ) -> int:
         """
         :return int:
             The port used by the server (which may later be used to connect
@@ -81,12 +88,13 @@ class RemoteFSObserver(object):
         assert self.port is None, "RemoteFSObserver already initialized."
         import subprocess
         from robocorp_ls_core import remote_fs_observer__main__
-        import time
 
         args = [sys.executable, "-u", remote_fs_observer__main__.__file__]
         if log_file:
             args.append(f"--log-file={log_file}")
-            args.append(f"-vv")
+
+        if verbose:
+            args.append("-" + ("v" * verbose))
 
         log.info("Initializing Remote FS Observer with the following args: %s", args)
         process = self.process = subprocess.Popen(
@@ -139,7 +147,7 @@ class RemoteFSObserver(object):
                     break
                 line = line.decode("utf-8", "replace")
                 sys.stderr.write(line)
-                log.info("Remote FS observer stderr: %s", line)
+                log.debug("Remote FS observer stderr: %s", line)
 
         t = threading.Thread(target=read_fs_observer_stderr)
         t.daemon = True
@@ -254,7 +262,7 @@ class RemoteFSObserver(object):
                 "Server communication is not initialized. start_server() or connect_to_server() must be called before notifying of changes."
             )
 
-        on_change_id: int = self._next_id()
+        on_change_id: str = self._next_id()
         path_args = [{"path": p.path, "recursive": p.recursive} for p in paths]
 
         remote_fs_watch = _RemoteFSWatch(self, on_change_id, on_change, call_args)
@@ -273,7 +281,7 @@ class RemoteFSObserver(object):
         )
         # Wait for the command to be acknowledged...
         if not remote_fs_watch.acknowledged.wait(5):
-            log.info("Command to notify on change not acknowledged!")
+            log.info(f"Command to notify on change not acknowledged. Paths: {paths}!")
         return remote_fs_watch
 
     def _on_read(self, msg):
