@@ -45,6 +45,11 @@ class PathInfo(object):
     def __hash__(self, *args, **kwargs):
         return hash(tuple(self.path, self.recursive))
 
+    def __str__(self):
+        return f"PathInfo[{self.path}, {self.recursive}]"
+
+    __repr__ = __str__
+
 
 class IFSCallback(Protocol):
     def __call__(self, src_path, *call_args):
@@ -427,6 +432,13 @@ class _WatchdogObserver(object):
                         return
                 # Note: notify on directory and file changes.
                 on_change(event.src_path, *call_args)
+                try:
+                    dest_path = event.dest_path
+                except AttributeError:
+                    pass
+                else:
+                    if dest_path:
+                        on_change(dest_path, *call_args)
 
         handler = _Handler()
         watches = []
