@@ -511,7 +511,14 @@ class Workspace(object):
             yield from folder._iter_all_doc_uris(extensions)
 
     def dispose(self):
-        pass
+        self._check_in_mutate_thread()
+
+        # Stop tracking folders and clear doc references.
+        for folder_uri in list(self._folders.keys()):
+            self.remove_folder(folder_uri)
+
+        self._docs = {}
+        self._filesystem_docs = {}
 
     def __typecheckself__(self) -> None:
         from robocorp_ls_core.protocols import check_implements
@@ -640,7 +647,7 @@ class Document(object):
         self.__line_start_offsets = line_start_offset_to_info
         return line_start_offset_to_info
 
-    def offset_to_line_col(self, offset):
+    def offset_to_line_col(self, offset: int) -> Tuple[int, int]:
         if offset < 0:
             raise ValueError("Expected offset to be >0. Found: %s" % (offset,))
 
@@ -732,7 +739,7 @@ class Document(object):
                 return len(lines), 0
             return len(lines) - 1, len(last_line)
 
-    def get_last_line_col_with_contents(self, contents) -> Tuple[int, int]:
+    def get_last_line_col_with_contents(self, contents: str) -> Tuple[int, int]:
         if not contents:
             raise ValueError("Contents not specified.")
 
